--[[
Abilities.lua
Copyright (c) 2006 by Markus Inger, 2006 by Caeryn Dryad, 2007-2009 by Horacio Hoyos

This file is part of DHUD3.

    DHUD3 is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    DHUD3 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DHUD3.  If not, see <http://www.gnu.org/licenses/>.
]]
local DHUD3 = LibStub("AceAddon-3.0"):GetAddon("DHUD3");
local L = LibStub("AceLocale-3.0"):GetLocale("DHUD3");

local MODNAME = "Abilities";
local Auras = DHUD3:NewModule(MODNAME, "AceEvent-3.0");

--Local Defaults
local db
local defaults = {
	profile = {
        side = "l";
		scale = 1;
        colors = {
            full = { 1, 1, 1 },
            med = { 255/255, 125/255, 125/255 },
            low = { 255/255, 65/255, 0 }      
        },
    }
}

local optGetter, optSetter, colorGetter, colorSetter
do
	local mod = Abilities
	function optGetter(info)
		local key = info[#info];
		return db[key];
	end

	function optSetter(info, value)
		local key = info[#info];
		db[key] = value;
		mod:Refresh();
	end
    
    function colorGetter (info)
        local key1, key2 = info[#info-1], info[#info];
		return db[key1][key2][1], db[key1][key2][2], db[key1][key2][3];
	end
    
    function colorSetter (info, r, g, b) 
        local key1, key2, key3 = info[#info-2], info[#info-1], info[#info];
        db[key1][key2][key3][1] = r;
        db[key1][key2][key3][2] = g;
        db[key1][key2][key3][3] = b;
        mod:Refresh();
    end
	
end

--Local Options
local options
local function getOptions()
	if not options then
        --Options table
    	options = {
    		type = "group",
			name = L["Abilities"],
			arg = MODNAME,
			get = optGetter,
			set = optSetter,
    		args = {
                enabled = {
                    type = "toggle",
                    order = 1,
                    name = L["Enable Abilities"],
                    get = function() return DHUD3:GetModuleEnabled(MODNAME) end,
                    set = function(info, value) DHUD3:SetModuleEnabled(MODNAME, value) end,
                },
			},
		}
	end
end
